x3Dtorus_unif: This function samples n points from the surface or the 3D...

Description Usage Arguments

View source: R/data.R

Description

This function samples n points from the surface or the 3D torus uniformly. This function is tentative. There is no guarantee that points are sampled unifomly.

Usage

1
x3Dtorus_unif(n, r, R1, R2)

Arguments

n

the number of points in the sample.

r

the smallest radius of 3D torus.

R1

the largest radius of 3D torus.

R2

the medim radius of 3D torus.


jetstreamokayasu/usephacm documentation built on March 12, 2021, 6:30 a.m.